import { Network } from '../Network';
import { SharedGroup } from './SharedGroup';
/**
 * Manager for all group instances that a node is a member of.
 */
export declare class GroupManager {
    private readonly net;
    /**
     * Debugger for log messages.
     */
    private readonly debug;
    private readonly groups;
    /**
     * Nodes currently being tracked.
     */
    private readonly nodes;
    private version;
    private gossipTimer;
    constructor(net: Network);
    /**
     * Handle a node becoming available. In this case ask the node to send
     * us all the groups it is a member of.
     *
     * @param node -
     *   node that is available
     */
    private handleNodeAvailable;
    /**
     * Handle a node becoming unavailable. This will remove it from all
     * groups that are currently active.
     *
     * @param node -
     *   node that is no longer available
     */
    private handleNodeUnavailable;
    private gossip;
    private handleMessage;
    /**
     * Handle an incoming request to join an group.
     *
     * @param node -
     *   node message comes from
     * @param msg -
     *   message received
     */
    private handleGroupJoin;
    /**
     * Handle an incoming request to leave an group.
     *
     * @param node -
     *   node message comes from
     * @param msg -
     *   message describing group being left
     */
    private handleGroupLeave;
    /**
     * Handle incoming information about all the groups a node is a member
     * of.
     *
     * @param node -
     *   node message comes from
     * @param msg -
     *   message containing group membership
     */
    private handleGroupMembership;
    /**
     * Handle a request by another node to tell us about the groups we are
     * a member of.
     *
     * @param node -
     *   node that requested our membership
     * @param msg -
     *   message containing query information
     */
    private handleGroupQuery;
    getSharedGroup(id: string): () => SharedGroup;
    private ensureSharedGroup;
}
//# sourceMappingURL=GroupManager.d.ts.map